#
# spec file for package kodi
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Please edit kodi.spec and kodi.changes only. *-noX.* files are generated from
# kodi.* files with the pre_checkin.sh script
%define kodi_version Jarvis
%define _kodi_addons_dir %{_datadir}/kodi/addons
# kodi can be built without X support when openGL ES is used (mainly used on ARM boards used as media center)
%define noX_build 0
%if %{noX_build}
# no X build needs openGL ES
%bcond_with enable_opengl
%bcond_without enable_opengles
%else
%ifarch %arm armv6l armv6hl
%bcond_with enable_opengl
%bcond_without enable_opengles
%else
%bcond_without enable_opengl
%bcond_with enable_opengles
%endif
%endif

%define kodi_platform none
%define kodi_player none

Name:           kodi.binary-addons
Version:        16.1
Release:        3.7
Summary:        Binary Addons for Kodi
License:        GPL-2.0+ and GPL-3.0+
Group:          Productivity/Multimedia/Video/Players
Url:            http://kodi.tv/
Source0:        https://github.com/xbmc/xbmc/archive/%{version}-%{kodi_version}.tar.gz
Source1:        kodi.binary-addons.spec.packages.inc
Source2:        kodi.binary-addons.spec.files.inc
Source3:        kodi.binary-addons.tar
Source4:        repo-binary-addons.%{kodi_version}.tar.bz2
Source5:        kodi-platform-15edaf7.tar.gz
Patch1:         cmake-binary-addons.patch
Patch2:         addon-helpers_lib64.patch
# PATCH-PACKMAN kodi.binary-addons-audiodecoder.ncsf-gcc5.3.patch - fixes compiling of audiodecoder.ncsf with gcc > 4.8, suse_version >= 1320
Patch3:         kodi.binary-addons-audiodecoder.ncsf-gcc5.3.patch
# PATCH-PACKMAN kodi.binary-addons-screensavers.rsxs-upstream-stdbool_h.patch - fixes compiling of screensavers.rsxs with gcc > 4.8, suse_version >= 1320
Patch4:         kodi.binary-addons-screensavers.rsxs-upstream-stdbool_h.patch
Patch5:         kodi.binary-addons.xbmc_pvr_dll.patch

BuildRequires:  autoconf 
BuildRequires:  automake
BuildRequires:  ccache
BuildRequires:  cmake 
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  jsoncpp-devel
%if %{noX_build}
BuildRequires:  kodi-noX-devel
%else
BuildRequires:  kodi-devel
%endif
BuildRequires:  tinyxml-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  libSOIL-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(flac)
BuildRequires:  libhdhomerun-devel
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libprojectM)
BuildRequires:  pkgconfig(platform)
BuildRequires:  pkgconfig(tinyxml2)
BuildRequires:  pkgconfig(vorbis)

# kodi needs the same libtag version which was used to build against
%requires_eq    libtag1
%if !%{noX_build}
BuildRequires:  xorg-x11-devel
%endif
%if %{with enable_opengl}
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(vdpau)
%endif

%if %{with enable_opengles}
%if %{kodi_platform} == "none"
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGLESv2-devel
%else
%if %{kodi_platform} == "raspberry-pi" || %{kodi_platform} == "raspberry-pi2" 
BuildRequires:  raspberrypi-userland-devel
%endif
%endif
%endif

# glxinfo is needed to check hw accel
%if 0%{?suse_version} >= 1220
%if !%{noX_build}
Requires:       Mesa-demo-x
Requires:       xdpyinfo
%endif
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    ppc64
Requires:       kodi = %{version}
#Requires:       libjsoncpp1

%description 
Binary Addons for Kodi Media Center

%include %{SOURCE1} 

%prep
%setup -q -n xbmc-%{version}-%{kodi_version}
%patch1
%ifarch x86_64
%patch2
%endif
%patch5 -p1

pushd project/cmake/addons
tar xvf %{SOURCE3} 
mkdir -pv build/bootstrap/binary-addons/src
cp -v %{SOURCE4} build/bootstrap/binary-addons/src

#remove deps that are already installed using BuildRequires 
rm -rf depends/common/{platform,tinyxml}
rm -f  depends/common/kodi-platform/deps.txt
tar xf %{SOURCE5} --strip-components=1 -C depends/common/kodi-platform
echo "kodi-platform file://../depends/common/kodi-platform" > depends/common/kodi-platform/kodi-platform.txt
popd

%build
pushd project/cmake/addons
%cmake \
%ifarch i586
    -DCMAKE_C_FLAGS='-msse' \
%endif
    -DBUILD_DIR=build \
    -DBUILD_SHARED_LIBS=1 \
    -DNEED_SUDO=FALSE \
    -DAPP_LIB_DIR=%{buildroot}%{_libdir}/kodi/ \
    -DCMAKE_INSTALL_LIBDIR=%{buildroot}%{_libdir}/kodi/ \
    -DCMAKE_INSTALL_PREFIX=%{buildroot}%{_prefix} 

# Tumbleweed and Factory have GCC 5.x ATM (20160309), source needs patching for this
%if 0%{?suse_version} > 1320
  # patch audiodecoders.ncsf
  patch -p0 < %{PATCH3}
  # patch screensavers.rsxs
  patch screensavers.rsxs/lib/rsxs-1.0/lib/stdbool.in.h %{PATCH4}
%endif

# fake buildtime in audiodecoder.qsf
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
for file in audiodecoder.qsf/lib/Highly_Quixotic/Core/qsound.c \
            audiodecoder.ssf/lib/Highly_Theoretical/Core/Starscream/star.c \
            audiodecoder.ssf/lib/Highly_Theoretical/Core/sega.c \
            audiodecoder.timidity/lib/timidity/timidity/speex_a.c; do
  sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" $file
done

make VERBOSE=1 %{?_smp_mflags}
popd

%install
#make DESTDIR=%{buildroot} install %{?_smp_mflags}

%fdupes %{buildroot}

%files
%defattr(-,root,root)
%dir %{_libdir}/kodi
%dir %{_datadir}/kodi
%{_libdir}/kodi/prepare-env.cmake


%include %{SOURCE2} 

%changelog
* Sat Aug  6 2016 olaf@aepfle.de
- Adjust BuildRequires libhdhomerun-devel
  Sun Apr 24 13:06:49 UTC 2016 - sagiben at gmail dot com
- Version update to Kodi 16.1 Jarvis
  https://kodi.tv/kodi-16-1-jarvis-mark-xvi
* Wed Mar  9 2016 guillaume@opensuse.org
- Fix noX builds
* Wed Mar  9 2016 obs@botter.cc
- fix compiling of audiodecoder.ncsf and screensavers.rsxs with
  gcc 5.x (Tumbleweed and Factory)
- replace __DATE__ in audiodecoder.qsf, audiodecoder.ssf and
  audiodecoder.timidity
  Sun Feb 14 10:17:23 UTC 2016 - sagiben at gmail.com
- Separate kodi.binary addon package from Kodi
